@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -80,7 +80,7 @@ __all__ = ("CodePipelineClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -128,7 +128,7 @@ class Exceptions:
 
 class CodePipelineClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html)
     """
 
@@ -145,7 +145,7 @@ class CodePipelineClient(BaseClient):
         Returns information about a specified job and whether that job has been received
         by the job worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#acknowledge_job)
         """
 
@@ -155,7 +155,7 @@ class CodePipelineClient(BaseClient):
         """
         Confirms a job worker has received the specified job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#acknowledge_third_party_job)
         """
 
@@ -163,7 +163,7 @@ class CodePipelineClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#can_paginate)
         """
 
@@ -176,24 +176,24 @@ class CodePipelineClient(BaseClient):
         inputArtifactDetails: "ArtifactDetailsTypeDef",
         outputArtifactDetails: "ArtifactDetailsTypeDef",
         settings: "ActionTypeSettingsTypeDef" = None,
-        configurationProperties: List["ActionConfigurationPropertyTypeDef"] = None,
-        tags: List["TagTypeDef"] = None
+        configurationProperties: Sequence["ActionConfigurationPropertyTypeDef"] = None,
+        tags: Sequence["TagTypeDef"] = None
     ) -> CreateCustomActionTypeOutputTypeDef:
         """
         Creates a new custom action that can be used in all pipelines associated with
         the AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#create_custom_action_type)
         """
 
     def create_pipeline(
-        self, *, pipeline: "PipelineDeclarationTypeDef", tags: List["TagTypeDef"] = None
+        self, *, pipeline: "PipelineDeclarationTypeDef", tags: Sequence["TagTypeDef"] = None
     ) -> CreatePipelineOutputTypeDef:
         """
         Creates a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#create_pipeline)
         """
 
@@ -203,7 +203,7 @@ class CodePipelineClient(BaseClient):
         """
         Marks a custom action as deleted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_custom_action_type)
         """
 
@@ -211,7 +211,7 @@ class CodePipelineClient(BaseClient):
         """
         Deletes the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_pipeline)
         """
 
@@ -219,7 +219,7 @@ class CodePipelineClient(BaseClient):
         """
         Deletes a previously created webhook by name.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_webhook)
         """
 
@@ -228,7 +228,7 @@ class CodePipelineClient(BaseClient):
         Removes the connection between the webhook that was created by CodePipeline and
         the external tool with events to be detected.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#deregister_webhook_with_third_party)
         """
 
@@ -244,7 +244,7 @@ class CodePipelineClient(BaseClient):
         Prevents artifacts in a pipeline from transitioning to the next stage in the
         pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#disable_stage_transition)
         """
 
@@ -254,21 +254,21 @@ class CodePipelineClient(BaseClient):
         """
         Enables artifacts in a pipeline to transition to a stage in a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#enable_stage_transition)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#generate_presigned_url)
         """
 
@@ -279,7 +279,7 @@ class CodePipelineClient(BaseClient):
         Returns information about an action type created for an external provider, where
         the action is to be used by customers of the external provider.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_action_type)
         """
 
@@ -287,7 +287,7 @@ class CodePipelineClient(BaseClient):
         """
         Returns information about a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_job_details)
         """
 
@@ -295,7 +295,7 @@ class CodePipelineClient(BaseClient):
         """
         Returns the metadata, structure, stages, and actions of a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline)
         """
 
@@ -307,7 +307,7 @@ class CodePipelineClient(BaseClient):
         artifacts, the pipeline execution ID, and the name, version, and status of the
         pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline_execution)
         """
 
@@ -316,7 +316,7 @@ class CodePipelineClient(BaseClient):
         Returns information about the state of a pipeline, including the stages and
         actions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline_state)
         """
 
@@ -326,7 +326,7 @@ class CodePipelineClient(BaseClient):
         """
         Requests the details of a job for a third party action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_third_party_job_details)
         """
 
@@ -341,7 +341,7 @@ class CodePipelineClient(BaseClient):
         """
         Lists the action executions that have occurred in a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_action_executions)
         """
 
@@ -356,7 +356,7 @@ class CodePipelineClient(BaseClient):
         Gets a summary of all AWS CodePipeline action types associated with your
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_action_types)
         """
 
@@ -366,7 +366,7 @@ class CodePipelineClient(BaseClient):
         """
         Gets a summary of the most recent executions for a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_pipeline_executions)
         """
 
@@ -376,7 +376,7 @@ class CodePipelineClient(BaseClient):
         """
         Gets a summary of all of the pipelines associated with your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_pipelines)
         """
 
@@ -386,7 +386,7 @@ class CodePipelineClient(BaseClient):
         """
         Gets the set of key-value pairs (metadata) that are used to manage the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_tags_for_resource)
         """
 
@@ -396,7 +396,7 @@ class CodePipelineClient(BaseClient):
         """
         Gets a listing of all the webhooks in this AWS Region for this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_webhooks)
         """
 
@@ -405,12 +405,12 @@ class CodePipelineClient(BaseClient):
         *,
         actionTypeId: "ActionTypeIdTypeDef",
         maxBatchSize: int = None,
-        queryParam: Dict[str, str] = None
+        queryParam: Mapping[str, str] = None
     ) -> PollForJobsOutputTypeDef:
         """
         Returns information about any jobs for AWS CodePipeline to act on.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#poll_for_jobs)
         """
 
@@ -420,7 +420,7 @@ class CodePipelineClient(BaseClient):
         """
         Determines whether there are any third party jobs for a job worker to act on.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#poll_for_third_party_jobs)
         """
 
@@ -435,7 +435,7 @@ class CodePipelineClient(BaseClient):
         """
         Provides information to AWS CodePipeline about new revisions to a source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_action_revision)
         """
 
@@ -451,7 +451,7 @@ class CodePipelineClient(BaseClient):
         """
         Provides the response to a manual approval request to AWS CodePipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_approval_result)
         """
 
@@ -461,7 +461,7 @@ class CodePipelineClient(BaseClient):
         """
         Represents the failure of a job as returned to the pipeline by a job worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_job_failure_result)
         """
 
@@ -472,12 +472,12 @@ class CodePipelineClient(BaseClient):
         currentRevision: "CurrentRevisionTypeDef" = None,
         continuationToken: str = None,
         executionDetails: "ExecutionDetailsTypeDef" = None,
-        outputVariables: Dict[str, str] = None
+        outputVariables: Mapping[str, str] = None
     ) -> None:
         """
         Represents the success of a job as returned to the pipeline by a job worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_job_success_result)
         """
 
@@ -488,7 +488,7 @@ class CodePipelineClient(BaseClient):
         Represents the failure of a third party job as returned to the pipeline by a job
         worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_third_party_job_failure_result)
         """
 
@@ -505,17 +505,17 @@ class CodePipelineClient(BaseClient):
         Represents the success of a third party job as returned to the pipeline by a job
         worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_third_party_job_success_result)
         """
 
     def put_webhook(
-        self, *, webhook: "WebhookDefinitionTypeDef", tags: List["TagTypeDef"] = None
+        self, *, webhook: "WebhookDefinitionTypeDef", tags: Sequence["TagTypeDef"] = None
     ) -> PutWebhookOutputTypeDef:
         """
         Defines a webhook and returns a unique webhook URL generated by CodePipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_webhook)
         """
 
@@ -524,7 +524,7 @@ class CodePipelineClient(BaseClient):
         Configures a connection between the webhook that was created and the external
         tool with events to be detected.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#register_webhook_with_third_party)
         """
 
@@ -539,7 +539,7 @@ class CodePipelineClient(BaseClient):
         """
         Resumes the pipeline execution by retrying the last failed actions in a stage.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#retry_stage_execution)
         """
 
@@ -549,7 +549,7 @@ class CodePipelineClient(BaseClient):
         """
         Starts the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#start_pipeline_execution)
         """
 
@@ -564,23 +564,23 @@ class CodePipelineClient(BaseClient):
         """
         Stops the specified pipeline execution.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#stop_pipeline_execution)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Adds to or modifies the tags of the given resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes tags from an AWS resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#untag_resource)
         """
 
@@ -589,7 +589,7 @@ class CodePipelineClient(BaseClient):
         Updates an action type that was created with any supported integration model,
         where the action type is to be used by customers of the action type provider.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.update_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.update_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#update_action_type)
         """
 
@@ -599,7 +599,7 @@ class CodePipelineClient(BaseClient):
         """
         Updates a specified pipeline with edits or changes to its structure.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#update_pipeline)
         """
 
@@ -608,7 +608,7 @@ class CodePipelineClient(BaseClient):
         self, operation_name: Literal["list_action_executions"]
     ) -> ListActionExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactionexecutionspaginator)
         """
 
@@ -617,7 +617,7 @@ class CodePipelineClient(BaseClient):
         self, operation_name: Literal["list_action_types"]
     ) -> ListActionTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactiontypespaginator)
         """
 
@@ -626,14 +626,14 @@ class CodePipelineClient(BaseClient):
         self, operation_name: Literal["list_pipeline_executions"]
     ) -> ListPipelineExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelineexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelinespaginator)
         """
 
@@ -642,13 +642,13 @@ class CodePipelineClient(BaseClient):
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listtagsforresourcepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_webhooks"]) -> ListWebhooksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listwebhookspaginator)
         """
